#! /usr/bin/env node
"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const meow = require("meow");
const opn = require("opn");
const update_notifier_1 = require("update-notifier");
const server_1 = require("./server");
const pkg = require("../package.json");
new update_notifier_1.UpdateNotifier({ pkg }).notify();
const cli = meow(`
  Usage:
    $ npm-run-script-chain -f ./package.json
    $ nrsc -f ./package.json
`, {
    flags: {
        file: {
            alias: "f",
            type: "string",
        },
        port: {
            alias: "p",
            type: "string",
        },
        version: {
            alias: "v",
            type: "boolean",
        },
    },
});
const [baseDir = process.cwd()] = cli.input;
const cliArgs = cli.flags;
const main = async (commandLineArguments) => {
    if (!commandLineArguments.file) {
        console.log("$ npm-run-script-chain -f [file path]");
        return;
    }
    try {
        const server = new server_1.Server(baseDir, commandLineArguments.file);
        const serverAddress = await server.run(commandLineArguments.port || 8001);
        console.log(`open: ${serverAddress}`);
        opn(serverAddress);
    }
    catch (err) {
        console.log(err);
        throw err;
    }
};
main(cliArgs);
//# sourceMappingURL=cli.js.map