"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const Tree = require("paths-js/tree");
const React = require("react");
const components_1 = require("./components");
const children = (x) => {
    if (x.collapsed) {
        return [];
    }
    else {
        return x.children || [];
    }
};
class App extends React.Component {
    render() {
        const anchorList = components_1.makeAnchorList(this.props.anchors);
        return (React.createElement("div", { id: "root" },
            anchorList,
            React.createElement("div", { id: "tree" },
                React.createElement("svg", { width: "100%", height: "100%" },
                    React.createElement("g", { transform: "translate(80, 10)" },
                        this.curves(),
                        this.nodes())))));
    }
    curves() {
        return this.props.tree.curves.map((c, idx) => {
            return React.createElement("path", { key: `curves-${idx}`, d: c.connector.path.print(), fill: "none", stroke: "gray" });
        });
    }
    nodes() {
        return this.props.tree.nodes.map((n, idx) => {
            const position = "translate(" + n.point[0] + "," + n.point[1] + ")";
            const toggle = () => {
                n.item.collapsed = !n.item.collapsed;
                this.forceUpdate();
            };
            const text = children(n.item).length > 0 ? components_1.makeNodeComponent(n, { x: -10, y: 0 }) : components_1.makeNodeComponent(n, { x: 10, y: 0 });
            return (React.createElement("g", { transform: position, key: `node-${idx}` },
                React.createElement("circle", { fill: "white", stroke: "black", r: "5", cx: "0", cy: "0", onClick: toggle }),
                text));
        });
    }
}
exports.App = App;
exports.makeProps = (data, size, anchors) => {
    return {
        tree: Tree({
            data,
            children,
            width: size.width,
            height: size.height,
        }),
        size,
        anchors,
    };
};
//# sourceMappingURL=index.js.map