"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const fs = require("fs");
const http = require("http");
const path = require("path");
const React = require("react");
const server_1 = require("react-dom/server");
const url = require("url");
const components_1 = require("./components");
const htmlTemplate_1 = require("./htmlTemplate");
const index_1 = require("./index");
const parser_1 = require("./parser");
class Server {
    constructor(basePath, inputFile) {
        this.basePath = basePath;
        this.filePath = path.join(basePath, inputFile);
        this.app = http.createServer((req, res) => {
            let startKey = "Please set Query Params `?start=any`";
            if (req.url) {
                const { pathname, query } = url.parse(req.url, true);
                if (query && query.start && typeof query.start === "string") {
                    startKey = query.start;
                }
                if (pathname && pathname.match(/^\/dist\//) && this.loadDistDirectoryFile(res, pathname)) {
                    return;
                }
            }
            const pkg = this.getPackageJson();
            const hostname = req.headers.host;
            const anchors = Object.keys(pkg.scripts).map(key => ({
                text: key,
                href: `http://${hostname}/?start=${key}`,
            }));
            if (!(startKey in pkg.scripts)) {
                const menu = server_1.renderToStaticMarkup(components_1.makeAnchorList(anchors));
                res.write(htmlTemplate_1.getHtmlTemplate(menu));
                res.end();
                return;
            }
            const chainData = {
                name: startKey,
                children: [],
            };
            parser_1.makeChain(chainData, pkg);
            const props = index_1.makeProps(chainData, { width: 350, height: 300 }, anchors);
            const html = server_1.renderToStaticMarkup(React.createElement(index_1.App, Object.assign({}, props)));
            res.write(htmlTemplate_1.getHtmlTemplate(html));
            res.end();
        });
    }
    async run(port) {
        try {
            const server = await this.app.listen(port);
            const addr = server.address();
            if (typeof addr === "string") {
                return `http://localhost:${addr}/`;
            }
            else {
                return `http://localhost:${addr.port}/`;
            }
        }
        catch (err) {
            console.log(err);
            throw err;
        }
    }
    loadDistDirectoryFile(res, pathname) {
        const distFilePath = path.join(this.basePath, pathname);
        if (fs.existsSync(distFilePath) && fs.statSync(distFilePath).isFile()) {
            fs.createReadStream(distFilePath).pipe(res);
            return true;
        }
        return false;
    }
    getPackageJson() {
        return require(this.filePath);
    }
}
exports.Server = Server;
//# sourceMappingURL=server.js.map